import { AxiosError, toFormData } from 'axios'
import { useMutation as useRQMutation, UseMutationOptions } from 'react-query'
import { Animation, CreateAnimationRequest } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace CreateAnimationMutation {
  export type Params = CreateAnimationRequest
  export type Response = Animation

  const key = ['create', 'animation']

  export const mutationFn = (params: Params) =>
    axiosService
      .post<Response>(`/animations/`, toFormData(params))
      .then((res) => res.data)

  export const useMutation = (
    options: UseMutationOptions<
      Response,
      AxiosError,
      CreateAnimationRequest
    > = {}
  ) => {
    return useRQMutation(mutationFn, { ...options, mutationKey: key })
  }
}
